
#ifndef OCSYNC_EXPORT_H
#define OCSYNC_EXPORT_H

#ifdef CSYNC_STATIC_DEFINE
#  define OCSYNC_EXPORT
#  define CSYNC_NO_EXPORT
#else
#  ifndef OCSYNC_EXPORT
#    ifdef csync_EXPORTS
        /* We are building this library */
#      define OCSYNC_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define OCSYNC_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef CSYNC_NO_EXPORT
#    define CSYNC_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef CSYNC_DEPRECATED
#  define CSYNC_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef CSYNC_DEPRECATED_EXPORT
#  define CSYNC_DEPRECATED_EXPORT OCSYNC_EXPORT CSYNC_DEPRECATED
#endif

#ifndef CSYNC_DEPRECATED_NO_EXPORT
#  define CSYNC_DEPRECATED_NO_EXPORT CSYNC_NO_EXPORT CSYNC_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef CSYNC_NO_DEPRECATED
#    define CSYNC_NO_DEPRECATED
#  endif
#endif

#endif /* OCSYNC_EXPORT_H */
